==> svm-20.2.0-sources.jar: com/oracle/svm/core/posix/linux/LinuxImageSingletonsFeature.java <==
/*
 * Copyright (c) 2019, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.posix.linux;

import org.graalvm.nativeimage.ImageSingletons;
import org.graalvm.nativeimage.hosted.Feature;

import com.oracle.svm.core.CErrorNumber.CErrorNumberSupport;
import com.oracle.svm.core.annotate.AutomaticFeature;

@AutomaticFeature
class LinuxImageSingletonsFeature implements Feature {

    @Override
    public void afterRegistration(AfterRegistrationAccess access) {
        ImageSingletons.add(CErrorNumberSupport.class, new LinuxCErrorNumberSupport());
    }
}

==> svm-21.0.0-sources.jar: com/oracle/svm/core/posix/linux/LinuxImageSingletonsFeature.java <==
/*
 * Copyright (c) 2019, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.posix.linux;

import com.oracle.svm.core.c.libc.LibCBase;
import com.oracle.svm.core.posix.linux.libc.BionicLibC;
import com.oracle.svm.core.posix.linux.libc.LibCFeature;
import org.graalvm.nativeimage.ImageSingletons;
import org.graalvm.nativeimage.hosted.Feature;

import com.oracle.svm.core.CErrorNumber.CErrorNumberSupport;
import com.oracle.svm.core.annotate.AutomaticFeature;

import java.util.Collections;
import java.util.List;

@AutomaticFeature
class LinuxImageSingletonsFeature implements Feature {

    @Override
    public List<Class<? extends Feature>> getRequiredFeatures() {
        return Collections.singletonList(LibCFeature.class);
    }

    @Override
    public void afterRegistration(AfterRegistrationAccess access) {
        if (LibCBase.singleton() instanceof BionicLibC) {
            ImageSingletons.add(CErrorNumberSupport.class, new BionicCErrorNumberSupport());
        } else {
            ImageSingletons.add(CErrorNumberSupport.class, new LinuxCErrorNumberSupport());
        }
    }
}
